@@ -200,6 +200,8 @@ def show_sets_filter(response):
         else:
             cur_set['completed'] = False
 
+        cur_set['fullRoundText'] = node['fullRoundText']
+
         cur_set['bracketName'] = node['phaseGroup']['phase']['name']
         cur_set['bracketId'] = node['phaseGroup']['id']
 
@@ -696,6 +698,10 @@ def player_show_info_filter(response):
         player['country'] = response['data']['player']['user']['location']['country']
         player['state'] = response['data']['player']['user']['location']['state']
         player['city'] = response['data']['player']['user']['location']['city']
+    else:
+        player['country'] = None
+        player['state'] = None
+        player['city'] = None
         
     player['rankings'] = response['data']['player']['rankings']
 
